@@ -1,7 +1,7 @@
 /* Test.java */
 
 /* 
- * Copyright (C) 1997 Mark Boyns <boyns@sdsu.edu>
+ * Copyright (C) 1996-98 Mark Boyns <boyns@sdsu.edu>
  *
  * This file is part of Muffin.
  *
@@ -30,6 +30,7 @@ public class Test implements FilterFactory
 
     public void setManager (FilterManager manager)
     {
+	System.out.println ("Test running\n");
 	this.manager = manager;
     }
     
@@ -54,6 +55,10 @@ public class Test implements FilterFactory
 	return f;
     }
 
+    public void shutdown ()
+    {
+    }
+
     void save ()
     {
 	manager.save (this);
